# ChangeFinderPRO

Change points are abrupt variations in time series data. ... Detection of change points is useful in modelling and prediction of time series and is found in application areas such as medical condition monitoring, climate change detection, speech and image analysis, and human activity analysis